@@ -1,6 +1,3 @@
-#ifndef __DOS2UNIX_H
-#define __DOS2UNIX_H
-
 /*
  *  Copyright (C) 2009-2011 Erwin Waterlander
  *  Copyright (C) 1994-1995 Benjamin Lin.
@@ -28,6 +25,9 @@
  *  IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
+#ifndef __DOS2UNIX_H
+#define __DOS2UNIX_H
+
 #ifdef __GNUC__
 #ifndef strcmpi
 #  define strcmpi(s1, s2) strcasecmp(s1, s2)
@@ -221,21 +221,4 @@ static int D2UIso1252Table[256] =
   '\xf0', '\xf1', '\xf2', '\xf3', '\xf4', '\xf5', '\xf6', '\xf7', '\xf8', '\xf9', '\xfa', '\xfb', '\xfc', '\xfd', '\xfe', '\xff',
 };
 
-#ifdef ENABLE_NLS
-
-#include <libintl.h>
-#define _(String) gettext (String)
-#define gettext_noop(String) String
-#define N_(String) gettext_noop (String)
-
-#else
-
-#define _(String) (String)
-#define N_(String) String
-#define textdomain(Domain)
-#define bindtextdomain(Package, Directory)
-
-#endif
-
-
 #endif
